@@ -419,7 +419,9 @@ int check_connectedness()
 							fsck_send_msg
 							    (fsck_WILLFIXINCREF,
 							     fsck_ref_msg(msg_info_ptr->msg_inopfx),
-							     msg_info_ptr->msg_inonum);
+							     msg_info_ptr->msg_inonum,
+							     fsck_ref_msg(msg_info_ptr->msg_inopfx),
+							     this_inorec->parent_inonum);
 						} else {
 							/* no write access */
 							this_inorec->
