@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines Corp., 2000-2002
+ *   Copyright (C) International Business Machines Corp., 2000-2004
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -1745,7 +1745,8 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 	int intermed_rc = FSCK_OK;
 	int dtree_rc = FSCK_OK;
 	dxd_t *dxd_ptr;
-	int8_t xTree_ignore_alloc_blks = 0;
+	int8_t save_ignore_alloc_blks;
+	int8_t xt_ignore_alloc_blks = 0;
 
 	dxd_ptr = &(inoptr->di_dxd);
 	/* the data root dxd */
@@ -1793,8 +1794,11 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 	 * process the xtree if the new directory table is supported
 	 * and if the directory table data is not inline (index > 14)
 	 */
-	if (((sb_ptr->s_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX)
-	    && inoptr->di_next_index > MAX_INLINE_DIRTABLE_ENTRY + 1) {
+	if (sb_ptr->s_flag & JFS_DIR_INDEX)
+		inorecptr->check_dir_index = 1;
+
+	if ((sb_ptr->s_flag & JFS_DIR_INDEX) &&
+	    inoptr->di_next_index > MAX_INLINE_DIRTABLE_ENTRY + 1) {
 		/*
 		 * validate the tree contents and record the extents it
 		 * describes until and unless the tree is found to be corrupt
@@ -1806,59 +1810,6 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 		if (vdd_rc < FSCK_OK)
 			goto out;
 
-		if (inorecptr->selected_to_rls && inode_is_metadata(inorecptr)) {
-			vdd_rc = FSCK_BADMDDATAIDX;
-		} else if (inorecptr->ignore_alloc_blks) {
-			/* the tree info can't be used */
-			if (inode_is_metadata(inorecptr)) {
-				vdd_rc = FSCK_BADMDDATAIDX;
-			}
-			/*
-			 * reverse the notations made when recording the
-			 * extents for the tree.  Again, stop when the point
-			 * of corruption is found since that's where the
-			 * recording process was stopped.
-			 */
-			intermed_rc =
-			    xTree_processing(inoptr, inoidx, inorecptr,
-					     msg_info_ptr, FSCK_UNRECORD);
-			if (intermed_rc < 0) {
-				vdd_rc = intermed_rc;
-				goto out;
-			}
-			if (intermed_rc != FSCK_OK) {
-				if (vdd_rc == FSCK_OK) {
-					vdd_rc = intermed_rc;
-				}
-			}
-			if (!inorecptr->ignore_ea_blks) {
-				intermed_rc = backout_EA(inoptr, inorecptr);
-				if (intermed_rc < 0) {
-					vdd_rc = intermed_rc;
-					goto out;
-				}
-				if (intermed_rc != FSCK_OK) {
-					if (vdd_rc == FSCK_OK) {
-						vdd_rc = intermed_rc;
-					}
-				}
-				if (!inorecptr->ignore_acl_blks) {
-					intermed_rc =
-					    backout_ACL(inoptr, inorecptr);
-					if (intermed_rc < 0) {
-						vdd_rc = intermed_rc;
-						goto out;
-					}
-					if (intermed_rc != FSCK_OK) {
-						/* but something wrong */
-						if (vdd_rc == FSCK_OK) {
-							/* first problem seen */
-							vdd_rc = intermed_rc;
-						}
-					}
-				}
-			}
-		}
 	}
 
 	/* 
@@ -1866,11 +1817,15 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 	 * wrong but non-fatal with xTree_processing.  If
 	 * so, reset the bit to give dTree_processing a
 	 * clean slate to start with.  Set a flag to 
-	 * indicate that the error bit must be set later.
+	 * indicate that the directory index table is to be rebuilt.
 	 */
 	if (inorecptr->ignore_alloc_blks) {
-		xTree_ignore_alloc_blks = -1;
+		inorecptr->check_dir_index = 0;
+		inorecptr->rebuild_dirtable = 1;
 		inorecptr->ignore_alloc_blks = 0;
+		inorecptr->selected_to_rls = 0;
+		agg_recptr->corrections_needed = 1;
+		xt_ignore_alloc_blks = 1;
 	}
 	/*
 	 * validate the tree contents and record the extents it
@@ -1928,6 +1883,42 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 			}
 		}
 	}
+	if ((sb_ptr->s_flag & JFS_DIR_INDEX) &&
+	    (inoptr->di_next_index > MAX_INLINE_DIRTABLE_ENTRY + 1) &&
+	    (inorecptr->ignore_alloc_blks || inorecptr->rebuild_dirtable)) {
+
+		/*
+		 * ignore_alloc_blks needs to exactly reflect the results
+		 * of the xTree_processing step
+		 */
+		save_ignore_alloc_blks = inorecptr->ignore_alloc_blks;
+		inorecptr->ignore_alloc_blks = xt_ignore_alloc_blks;
+		/*
+		 * reverse the notations made when recording the
+		 * extents for the tree.  Again, stop when the point
+		 * of corruption is found since that's where the
+		 * recording process was stopped.
+		 */
+		intermed_rc =
+		    xTree_processing(inoptr, inoidx, inorecptr,
+				     msg_info_ptr, FSCK_UNRECORD);
+		if (intermed_rc < 0) {
+			vdd_rc = intermed_rc;
+			goto out;
+		}
+		if (intermed_rc != FSCK_OK) {
+			if (vdd_rc == FSCK_OK) {
+				vdd_rc = intermed_rc;
+			}
+		}
+		inorecptr->ignore_alloc_blks = save_ignore_alloc_blks;
+
+		/*
+		 * If we don't fix di_nblocks now, the inode will be
+		 * thrown away (even if dtree is good).
+		 */
+		inoptr->di_nblocks = agg_recptr->this_inode.all_blks;
+	}
       dtree_out:
 	/*
 	 * return the worse of the rc's for xtree and dtree processing
@@ -1935,13 +1926,6 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 	if (dtree_rc != FSCK_OK) {
 		vdd_rc = dtree_rc;
 	}
-	/* 
-	 * If there was a previous non-fatal error in 
-	 * xTree_processing, turn the error bit back on
-	 */
-	if (xTree_ignore_alloc_blks) {
-		inorecptr->ignore_alloc_blks = 1;
-	}
 
       out:
 	return (vdd_rc);
