@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines Corp., 2000-2002
+ *   Copyright (C) International Business Machines Corp., 2000-2004
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -1419,7 +1419,10 @@ int xTree_search(struct dinode *inoptr,
 	int8_t xad_chosen;
 	int64_t last_offset;
 
-	xtpg_ptr = (xtpage_t *) & (inoptr->di_btroot);
+	if (ISDIR(inoptr->di_mode))
+		xtpg_ptr = (xtpage_t *) & (inoptr->di_dirtable);
+	else
+		xtpg_ptr = (xtpage_t *) & (inoptr->di_btroot);
 
 	while ((!extent_located) && (!not_there) && (xs_rc == FSCK_OK)) {
 
