@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines Corp., 2000-2002
+ *   Copyright (C) International Business Machines Corp., 2000-2004
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -1152,6 +1152,7 @@ int report_problems_setup_repairs()
 		    (this_inorec->crrct_cumm_blks) ||
 		    (this_inorec->cant_chkea) ||
 		    (this_inorec->adj_entries) || 
+		    (this_inorec->rebuild_dirtable) || 
 		    ((this_inorec->unxpctd_prnts) && (!this_inorec->in_use))))
 			goto rpsr_next;    
 			
@@ -1416,6 +1417,18 @@ int report_problems_setup_repairs()
 			 */
 			fsck_send_msg(fsck_CANTCHKEA);
 		}
+		if ((rc == FSCK_OK) && (this_inorec->rebuild_dirtable)) {
+			if (agg_recptr->processing_readwrite) {
+				/* we can fix this */
+				agg_recptr->corrections_approved = 1;
+				fsck_send_msg(fsck_WILLFIX_DI_TABLE);
+			} else {
+				/* we don't have write access */
+				this_inorec->rebuild_dirtable = 0;
+				agg_recptr->ag_dirty = 1;
+				fsck_send_msg(fsck_DI_TABLE);
+			}
+		}
 
       rpsr_next:
 		if (rc == FSCK_OK) {
@@ -1774,7 +1787,7 @@ void parse_parms(int argc, char **argv)
 		/**************************
 		 * Specify journal device *
 		 **************************/
-			strcpy(log_device, optarg);
+			strncpy(log_device, optarg, sizeof (log_device) - 1);
 			break;
 
 		case 'J':
@@ -1936,6 +1949,10 @@ int phase0_processing()
 		printf("JFS fsck back from logredo, rc = %ld \n",
 		       agg_recptr->logredo_rc);
 #endif
+		/* If superblock is clean and log in use, it's okay */
+		if ((agg_recptr->logredo_rc == LOG_IN_USE) &&
+		    (sb_ptr->s_state == FM_CLEAN))
+			agg_recptr->logredo_rc = FSCK_OK;
 
 		if (agg_recptr->logredo_rc != FSCK_OK) {
 			/* logredo failed */
@@ -1957,7 +1974,7 @@ int phase0_processing()
 	if ( (agg_recptr->parm_options[UFS_CHKDSK_IFDIRTY] &&
 	    (!agg_recptr->parm_options_nologredo) &&
 	    ((sb_ptr->s_state & FM_DIRTY) != FM_DIRTY)
-	    && (agg_recptr->logredo_rc == FSCK_OK)
+	     && (agg_recptr->logredo_rc == FSCK_OK)
 	    && ((sb_ptr->s_flag & JFS_BAD_SAIT) != JFS_BAD_SAIT)) ||
 	    agg_recptr->parm_options_logredo_only ) {
 		/*
@@ -2063,7 +2080,10 @@ int phase1_processing()
 	 * in the call that follows) has an EA attached.
 	 */
 	establish_ea_iobuf();
-	
+
+	if ((p1_rc = allocate_dir_index_buffers()) != FSCK_OK)
+		goto p1_exit;
+
 	/* verify the metadata
 	 * inodes for all filesets in the aggregate
 	 */
@@ -2075,7 +2095,7 @@ int phase1_processing()
 	 */
 	if ((p1_rc = fatal_dup_check()) != FSCK_OK)
 		goto p1_exit;
-		
+
 	/* validate the fileset inodes */
 	p1_rc = validate_fs_inodes();
 	
@@ -2599,6 +2619,7 @@ int repair_fs_inodes()
 			|| (this_inorec->crrct_cumm_blks)
 			|| (this_inorec->inlineea_on)
 			|| (this_inorec->inlineea_off)
+			|| (this_inorec->rebuild_dirtable)
 			|| (this_inorec->reconnect)
 			|| (this_inorec->link_count != 0))))
 			goto rfsi_prime_dasd;
@@ -2754,6 +2775,13 @@ int repair_fs_inodes()
 				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
 				      msg_info_ptr->msg_inonum);
 		}
+		if ((rfsi_rc == FSCK_OK) && (this_inorec->rebuild_dirtable)) {
+			rfsi_rc = rebuild_dir_index(ino_ptr, this_inorec);
+			if (rfsi_rc == FSCK_OK)
+				fsck_send_msg(fsck_DI_TABLE_FXD,
+					fsck_ref_msg(msg_info_ptr->msg_inopfx),
+					msg_info_ptr->msg_inonum);
+		}
 		if (!((rfsi_rc == FSCK_OK)
 		    && (this_inorec->adj_entries)))
 			goto rfsi_inode_put;    
