@@ -1,33 +1,23 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 2 of the License, or 
  *   (at your option) any later version.
- *
+ * 
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software
+ *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- *   MODULE_NAME:		xfsck.h
- *
- *   COMPONENT_NAME: 	jfs utilities
- *
- *	common data & function prototypes
- *
  */
-
 #ifndef H_XFSCK
 #define H_XFSCK
 
-typedef int    retcode_t;
-
 /*
    -------------------------- system includes  --------------------------
 */
@@ -47,13 +37,6 @@ typedef int    retcode_t;
 */
 
 #include "jfs_types.h"
-
-/* Prevent conflict between unikern.h & uconv.h */
-#undef ULS_INVALID
-#undef ULS_ILLEGALSEQUENCE
-#undef ULS_BADOBJECT
-#undef ULS_BUFFERFULL
-
 #include "jfs_dinode.h"
 #include "jfs_dmap.h"
 #include "jfs_filsys.h"
@@ -77,55 +60,25 @@ typedef int    retcode_t;
 /* Stuff for handling extended attributes. */
 #ifndef OS2
 
-    typedef struct _FEA     /* fea */
-    {
-       uint8_t   fEA;       /* flags                              */
-       uint8_t   cbName;    /* name length not including NULL */
-       uint16_t  cbValue;   /* value length */
-    } FEA;
-    typedef FEA *PFEA;
+struct FEA {			/* fea */
+	uint8_t fEA;		/* flags                              */
+	uint8_t cbName;		/* name length not including NULL */
+	uint16_t cbValue;	/* value length */
+};
 
-    /* flags for _FEA.fEA */
-    #define FEA_NEEDEA         0x80     /* need EA bit */
+/* flags for FEA.fEA */
+#define FEA_NEEDEA         0x80	/* need EA bit */
 
-    typedef struct _FEALIST    /* feal */
-    {
-       uint32_t  cbList;       /* total bytes of structure including full list */
-       FEA       list[1];      /* variable length FEA structures */
-    } FEALIST;
-    typedef FEALIST *PFEALIST;
+struct FEALIST {		/* feal */
+	uint32_t cbList;	/* total bytes of structure including full list */
+	struct FEA list[1];	/* variable length FEA structures */
+};
 
-   typedef struct _FEA2       /* fea2 */
-   {
-      uint32_t  oNextEntryOffset; /* new field */
-      uint8_t   fEA;
-      uint8_t   cbName;
-      uint16_t  cbValue;
-      char      szName[1];        /* new field */
-   } FEA2;
-   typedef FEA2 *PFEA2;
-
-   typedef struct _FEA2LIST     /* fea2l */
-   {
-      uint32_t  cbList;
-      FEA2      list[1];
-   } FEA2LIST;
-   typedef FEA2LIST *PFEA2LIST;
-
-  typedef struct _RESULTCODES
-  {
-    uint16_t  codeTerminate;
-    uint16_t  codeResult;
-  } RESULTCODES;
-  typedef RESULTCODES *PRESULTCODES;
-
-  #define ERROR_EA_LIST_INCONSISTENT  255
-
-  typedef struct nls_table * UconvObject;
+#define ERROR_EA_LIST_INCONSISTENT  255
 
 #endif
 
-extern int jfs_ValidateFEAList( FEALIST *, unsigned long * );
+extern int jfs_ValidateFEAList(struct FEALIST *, unsigned long *);
 
 /* ***** IMPORTANT ***** IMPORTANT ***** IMPORTANT ***** IMPORTANT *****
  *
@@ -150,7 +103,6 @@ extern int jfs_ValidateFEAList( FEALIST *, unsigned long * );
 #define fscklog_var_text 1
 #define fscklog_literal  2
 
-
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
   * The following are used to access the columns of
@@ -191,13 +143,13 @@ extern int jfs_ValidateFEAList( FEALIST *, unsigned long * );
 #define jfs_msgfile      1
 
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
- * The following are used for reporting storage allocation
- * failures.
- */
+    * The following are used for reporting storage allocation
+    * failures.
+  */
 
 #ifndef _JFS_FSCKDIRE
 
-void report_dynstg_error ( void );
+void report_dynstg_error(void);
 
 #define  dynstg_unknown          0
 
@@ -237,151 +189,120 @@ void report_dynstg_error ( void );
 #define dynstg_treeStack_elem   26
 #define dynstg_fsckcbblbuf1     27
 #define dynstg_fsckcbblbuf2     28
-#define dynstg_inotbl           29                 
-#define dynstg_inoexttbl        30                 
-#define dynstg_fsit_iagtbl      31                 
-#define dynstg_fsit_inoexttbl   32                 
-#define dynstg_fsit_inotbl      33                 
-#define dynstg_ait_inotbl       34                 
-
-#endif /* ! _JFS_FSCKDIRE */
-
-
- /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
-  * The following are the possible values for current_fsck_phase
-  * which is declared in xchkdsk.c
-  *
-  */
-#define fsck_entry         16         /* x10 => entry linkage  */
-#define fsck_phase_initial 17         /* x11 => initialization */
-#define fsck_phase0         0
-#define fsck_phase1         1
-#define fsck_phase2         2
-#define fsck_phase3         3
-#define fsck_phase4         4
-#define fsck_phase5         5
-#define fsck_phase6         6
-#define fsck_phase7         7
-#define fsck_phase8         8
-#define fsck_phase9         9
-#define fsck_phase_final   32       /* x20 => cleanup        */
-#define fsck_exit          33       /* x21 => exit linkage   */
+#define dynstg_inotbl           29
+#define dynstg_inoexttbl        30
+#define dynstg_fsit_iagtbl      31
+#define dynstg_fsit_inoexttbl   32
+#define dynstg_fsit_inotbl      33
+#define dynstg_ait_inotbl       34
 
+#endif				/* ! _JFS_FSCKDIRE */
 
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
  * used during blockmap verify/rebuild
  *
  */
-typedef struct fsck_bmap_record {
-     char           eyecatcher[8];
-     fsblkidx_t     total_blocks;
-     fsblkidx_t     free_blocks;
-     int8_t         ctl_fctl_error;
-     int8_t         ctl_other_error;
-     char           rsvd0[2];
+struct fsck_bmap_record {
+	char eyecatcher[8];
+	int64_t total_blocks;
+	int64_t free_blocks;
+	int8_t ctl_fctl_error;
+	int8_t ctl_other_error;
+	char rsvd0[2];
 
-     char           bmpctlinf_eyecatcher[8];
-     dbmap_t        *bmpctl_bufptr;
-     agg_byteidx_t  bmpctl_agg_fsblk_offset;
-     char           rsvd1[4];
+	char bmpctlinf_eyecatcher[8];
+	struct dbmap *bmpctl_bufptr;
+	int64_t bmpctl_agg_fsblk_offset;
+	char rsvd1[4];
 
-     char           AGinf_eyecatcher[8];
-     fsblkidx_t     *AGFree_tbl;
-     int8_t         AGActive[MAXAG];
+	char AGinf_eyecatcher[8];
+	int64_t *AGFree_tbl;
+	int8_t AGActive[MAXAG];
 
-     char           dmapinf_eyecatcher[8];
-     reg_idx_t      dmappg_count;
-     reg_idx_t      dmappg_ordno;
-     reg_idx_t      dmappg_idx;
-     int8_t         *dmap_wsp_stree;
-     int8_t         *dmap_wsp_sleafs;
-     dmap_t         *dmap_bufptr;
-     agg_byteidx_t  dmap_agg_offset;
-     fsblkidx_t     dmap_1stblk;
-     int8_t         dmap_pmap_error;
-     int8_t         dmap_slfv_error;
-     int8_t         dmap_slnv_error;
-     int8_t         dmap_other_error;
-     char           rsvd2[4];
+	char dmapinf_eyecatcher[8];
+	uint32_t dmappg_count;
+	uint32_t dmappg_ordno;
+	uint32_t dmappg_idx;
+	int8_t *dmap_wsp_stree;
+	int8_t *dmap_wsp_sleafs;
+	struct dmap *dmap_bufptr;
+	int64_t dmap_agg_offset;
+	int64_t dmap_1stblk;
+	int8_t dmap_pmap_error;
+	int8_t dmap_slfv_error;
+	int8_t dmap_slnv_error;
+	int8_t dmap_other_error;
+	char rsvd2[4];
 
-     char           L0inf_eyecatcher[8];
-     reg_idx_t      L0pg_count;
-     reg_idx_t      L0pg_ordno;
-     reg_idx_t      L0pg_idx;
-     int8_t         *L0_wsp_stree;
-     int8_t         *L0_wsp_sleafs;
-     dmapctl_t      *L0_bufptr;
-     agg_byteidx_t  L0pg_agg_offset;
-     fsblkidx_t     L0pg_1stblk;
-     int8_t         L0_rsvd;
-     int8_t         L0pg_slfv_error;
-     int8_t         L0pg_slnv_error;
-     int8_t         L0pg_other_error;
-     char           rsvd3[4];
+	char L0inf_eyecatcher[8];
+	uint32_t L0pg_count;
+	uint32_t L0pg_ordno;
+	uint32_t L0pg_idx;
+	int8_t *L0_wsp_stree;
+	int8_t *L0_wsp_sleafs;
+	struct dmapctl *L0_bufptr;
+	int64_t L0pg_agg_offset;
+	int64_t L0pg_1stblk;
+	int8_t L0_rsvd;
+	int8_t L0pg_slfv_error;
+	int8_t L0pg_slnv_error;
+	int8_t L0pg_other_error;
+	char rsvd3[4];
 
-     char           L1inf_eyecatcher[8];
-     reg_idx_t      L1pg_count;
-     reg_idx_t      L1pg_ordno;
-     reg_idx_t      L1pg_idx;
-     int8_t         *L1_wsp_stree;
-     int8_t         *L1_wsp_sleafs;
-     dmapctl_t      *L1_bufptr;
-     agg_byteidx_t  L1pg_agg_offset;
-     fsblkidx_t     L1pg_1stblk;
-     int8_t         L1_rsvd;
-     int8_t         L1pg_slfv_error;
-     int8_t         L1pg_slnv_error;
-     int8_t         L1pg_other_error;
-     char           rsvd4[4];
-
-     char           L2inf_eyecatcher[8];
-     reg_idx_t      L2pg_count;
-     int8_t         *L2_wsp_stree;
-     int8_t         *L2_wsp_sleafs;
-     dmapctl_t      *L2_bufptr;
-     agg_byteidx_t  L2pg_agg_offset;
-     fsblkidx_t     L2pg_1stblk;
-     int8_t         L2pg_slfv_error;
-     int8_t         L2pg_slnv_error;
-     int8_t         L2pg_other_error;
-     char           rsvd5[5];
-     }  fsck_bmap_record;
+	char L1inf_eyecatcher[8];
+	uint32_t L1pg_count;
+	uint32_t L1pg_ordno;
+	uint32_t L1pg_idx;
+	int8_t *L1_wsp_stree;
+	int8_t *L1_wsp_sleafs;
+	struct dmapctl *L1_bufptr;
+	int64_t L1pg_agg_offset;
+	int64_t L1pg_1stblk;
+	int8_t L1_rsvd;
+	int8_t L1pg_slfv_error;
+	int8_t L1pg_slnv_error;
+	int8_t L1pg_other_error;
+	char rsvd4[4];
 
+	char L2inf_eyecatcher[8];
+	uint32_t L2pg_count;
+	int8_t *L2_wsp_stree;
+	int8_t *L2_wsp_sleafs;
+	struct dmapctl *L2_bufptr;
+	int64_t L2pg_agg_offset;
+	int64_t L2pg_1stblk;
+	int8_t L2pg_slfv_error;
+	int8_t L2pg_slnv_error;
+	int8_t L2pg_other_error;
+	char rsvd5[5];
+};
 
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
  * unicharacter name structure
  */
 struct uniname {
-           uint32_t  len_in_UniChars;
-           UniChar   name_in_UniChars[256];
+	uint32_t len_in_UniChars;
+	UniChar name_in_UniChars[256];
 };
 
-typedef struct uniname *UniCharname;
-
-
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
  * used to pass message inserts from one routine to another economically
  */
 struct fsck_ino_msg_info {
-   uint32_t  msg_inonum;
-   int       msg_inopfx;
-   int       msg_inotyp;
-   int       msg_dxdtyp;
-   };
-
-typedef struct fsck_ino_msg_info *fsck_msg_info_ptr;
+	uint32_t msg_inonum;
+	int msg_inopfx;
+	int msg_inotyp;
+	int msg_dxdtyp;
+};
 
 struct fsck_imap_msg_info {
-   iagno_t  msg_iagnum;
-   int32_t  msg_agnum;
-   int      msg_mapowner;
-   };
-
-typedef struct fsck_imap_msg_info *fsck_imap_msg_info_ptr;
-
+	int32_t msg_iagnum;
+	int32_t msg_agnum;
+	int msg_mapowner;
+};
 
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
@@ -397,7 +318,6 @@ typedef struct fsck_imap_msg_info *fsck_imap_msg_info_ptr;
 #define FSCK_FSIM_UNRECORD          7
 #define FSCK_FSIM_QUERY             8
 
-
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
   * The following are the values which may be displayed in
@@ -406,7 +326,6 @@ typedef struct fsck_imap_msg_info *fsck_imap_msg_info_ptr;
   */
 #define fsck_longdata_and_otherinline  1
 
-
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
  * The following define exit codes passed back by fsck.jfs 
@@ -708,25 +627,25 @@ typedef struct fsck_imap_msg_info *fsck_imap_msg_info_ptr;
 #define FSCK_INTERNAL_ERROR_67  -11067
 #define FSCK_INTERNAL_ERROR_68  -11068
 #define FSCK_INTERNAL_ERROR_69  -11069
-#define FSCK_INTERNAL_ERROR_70  -11070               
-#define FSCK_INTERNAL_ERROR_71  -11071               
-#define FSCK_INTERNAL_ERROR_72  -11072               
-#define FSCK_INTERNAL_ERROR_73  -11073               
-#define FSCK_INTERNAL_ERROR_74  -11074               
-#define FSCK_INTERNAL_ERROR_75  -11075               
-#define FSCK_INTERNAL_ERROR_76  -11076               
-#define FSCK_INTERNAL_ERROR_77  -11077               
-#define FSCK_INTERNAL_ERROR_78  -11078               
-#define FSCK_INTERNAL_ERROR_79  -11079               
-#define FSCK_INTERNAL_ERROR_80  -11080               
-#define FSCK_INTERNAL_ERROR_81  -11081               
-#define FSCK_INTERNAL_ERROR_82  -11082               
-#define FSCK_INTERNAL_ERROR_83  -11083               
-#define FSCK_INTERNAL_ERROR_84  -11084               
-#define FSCK_INTERNAL_ERROR_85  -11085               
-#define FSCK_INTERNAL_ERROR_86  -11086               
-#define FSCK_INTERNAL_ERROR_87  -11087               
-#define FSCK_INTERNAL_ERROR_88  -11088               
-#define FSCK_INTERNAL_ERROR_89  -11089               
+#define FSCK_INTERNAL_ERROR_70  -11070
+#define FSCK_INTERNAL_ERROR_71  -11071
+#define FSCK_INTERNAL_ERROR_72  -11072
+#define FSCK_INTERNAL_ERROR_73  -11073
+#define FSCK_INTERNAL_ERROR_74  -11074
+#define FSCK_INTERNAL_ERROR_75  -11075
+#define FSCK_INTERNAL_ERROR_76  -11076
+#define FSCK_INTERNAL_ERROR_77  -11077
+#define FSCK_INTERNAL_ERROR_78  -11078
+#define FSCK_INTERNAL_ERROR_79  -11079
+#define FSCK_INTERNAL_ERROR_80  -11080
+#define FSCK_INTERNAL_ERROR_81  -11081
+#define FSCK_INTERNAL_ERROR_82  -11082
+#define FSCK_INTERNAL_ERROR_83  -11083
+#define FSCK_INTERNAL_ERROR_84  -11084
+#define FSCK_INTERNAL_ERROR_85  -11085
+#define FSCK_INTERNAL_ERROR_86  -11086
+#define FSCK_INTERNAL_ERROR_87  -11087
+#define FSCK_INTERNAL_ERROR_88  -11088
+#define FSCK_INTERNAL_ERROR_89  -11089
 
 #endif
