@@ -31,10 +31,9 @@
  * includes from JFS fsck
  */
 #include "fsckwsp.h"
-#include "fsckmsgp.h"
+#include "fsck_message.h"
 #include "jfs_endian.h"
 
-#include "fsckmsge.h"
 #include "jfs_fscklog.h"
 
 #define fsck_READ  1
@@ -70,23 +69,9 @@ char xchklog_buffer[XCHKLOG_BUFSIZE];
   *
   *    values are assigned by the main jfs_fscklog routine
   */
-extern char message_parm_0[MAXPARMLEN];
-extern char message_parm_1[MAXPARMLEN];
-extern char message_parm_2[MAXPARMLEN];
-extern char message_parm_3[MAXPARMLEN];
-extern char message_parm_4[MAXPARMLEN];
-extern char message_parm_5[MAXPARMLEN];
-extern char message_parm_6[MAXPARMLEN];
-extern char message_parm_7[MAXPARMLEN];
-extern char message_parm_8[MAXPARMLEN];
-extern char message_parm_9[MAXPARMLEN];
-
-extern char *msgprms[10];
-extern short msgprmidx[10];
 extern char message_buffer_0[512];
 extern char *msgs_txt_ptr;
 extern unsigned long msgs_txt_maxlen;
-extern void send_msg(int, int);
 
 extern char *Vol_Label;
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
@@ -118,7 +103,7 @@ int open_outfile(void);
 
 int readwrite_device(int64_t, unsigned, unsigned *, void *, int);
 
-void record_msg(int, int);
+void record_msg(char *);
 
 int validate_super(int);
 
@@ -174,23 +159,12 @@ int xchklog(struct fscklog_record *local_recptr)
  */
 void extract_service_log()
 {
+	char *msg_txt;
 	int dsl_rc = 0;
-	int prmidx;
 	char *log_entry;
 	int log_entry_pos;
 	int bytes_left;
 	struct fscklog_entry_hdr *hdptr;
-	char *prmlit;
-	int8_t *prmtype;	/* array of parm types: 
-				 *	1 => text insert idx,
-				 *	2 => string literal
-				 */
-	int16_t *prmval;	/* array of parm values:
-				 *  if prmtype[i] == 1, 
-				 *	prmval[i] = index of text insert
-				 *  if prmtype[i] == 2, 
-				 *	prmval[i] = length of string literal
-				 */
 
 	local_recptr->fscklog_last_read = 0;
 
@@ -228,96 +202,28 @@ void extract_service_log()
 				    || (hdptr->entry_length < 0)
 				    || (hdptr->entry_length > bytes_left)) {
 					/* this isn't a valid log record length */
-					send_msg(fsck_CHKLOGINVALRCD, 0);
+					send_msg(fsck_CHKLOGINVALRCD);
 					local_recptr->this_buffer_last_message =
 					    -1;
 				} else {
 					/* the log record length looks ok */
-					if ((hdptr->msg_num < 0)
-					    || (hdptr->msg_num >
-						fsck_highest_msgid_defined)) {
-						/* this isn't a valid log record */
-						send_msg(fsck_CHKLOGINVALRCD,
-							  0);
-					} else if ((hdptr->num_parms < 0)
-						   || (hdptr->num_parms > 10)) {
-						/* invalid number of parms */
-						send_msg(fsck_CHKLOGINVALRCD,
-							  0);
-					} else {
-						/* 
-						 * set up for message inserts
-						 */
-						if (hdptr->num_parms != 0) {
-							/* there are parms */
-							prmtype =
-							    (int8_t *) &
-							    (log_entry
-							     [log_entry_pos]);
-							log_entry_pos +=
-							    hdptr->num_parms *
-							    sizeof (int8_t);
-							prmval = (short *)
-							    &(prmtype
-							      [hdptr->
-							       num_parms]);
-							log_entry_pos +=
-							    hdptr->num_parms *
-							    sizeof (short);
-							prmlit = (char *)
-							    &(log_entry
-							      [log_entry_pos]);
+					msg_txt = &log_entry[log_entry_pos];
 
-							prmidx = 0;
-							while (prmidx <
-							       hdptr->
-							       num_parms) {
-								if (prmtype
-								    [prmidx] ==
-								    fscklog_var_text)
-								{
-									/*  variable text insert */
-									msgprmidx
-									    [prmidx]
-									    =
-									    prmval
-									    [prmidx];
-								} else {
-									/* string literal insert */
-									msgprmidx
-									    [prmidx]
-									    = 0;
-									msgprms
-									    [prmidx]
-									    =
-									    prmlit;
-									prmlit =
-									    (char
-									     *)
-									    (prmlit
-									     +
-									     prmval
-									     [prmidx]);
-								}
-								prmidx += 1;
-							}
-						}
-						/* 
-						 * record the message in the output file
-						 */
-						record_msg(hdptr->msg_num,
-							   hdptr->num_parms);
-					}
+					/* 
+					 * record the message in the output file
+					 */
+					record_msg(msg_txt);
+					
 					/* 
 					 * set up for the next record 
 					 */
 					local_recptr->infile_buf_data_len +=
 					    hdptr->entry_length;
-					if (hdptr->msg_num == fsck_SESSEND) {
+					/*if (hdptr->msg_num == fsck_SESSEND) {
 						local_recptr->
 						    this_buffer_last_message =
 						    -1;
-					}
+						    }*/
 					if (local_recptr->infile_buf_data_len >=
 					    local_recptr->infile_buf_length) {
 						local_recptr->
@@ -350,7 +256,6 @@ void extract_service_log()
 int xchklog_final_processing()
 {
 	int pf_rc = 0;
-	int of_rc = 0;
 
 	/*
 	 * Close the device
@@ -371,7 +276,7 @@ int xchklog_final_processing()
 			       sizeof (char), local_recptr->outfile_buf_length,
 			       outfp);
 		}
-		of_rc = fclose(outfp);
+		fclose(outfp);
 	}
 
 	return (pf_rc);
@@ -418,33 +323,12 @@ int xchklog_fscklog_fill_buffer()
 		 * write failed or didn't read
 		 * correct number of bytes 
 		 */
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = fsck_metadata;
-		msgprms[1] = Vol_Label;
-		msgprmidx[1] = 0;
-		send_msg(fsck_URCVWRT, 2);
+		send_msg(fsck_URCVWRT, fsck_ref_msg(fsck_metadata), Vol_Label);
 
-		sprintf(message_parm_0, "%d", FSCK_BADREAD_FSCKLOG);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		sprintf(message_parm_1, "%d", io_rc);
-		msgprms[1] = message_parm_1;
-		msgprmidx[1] = 0;
-		sprintf(message_parm_2, "%d", fsck_READ);
-		msgprms[2] = message_parm_2;
-		msgprmidx[2] = 0;
-		sprintf(message_parm_3, "%lld",
-			(long long) local_recptr->infile_agg_offset);
-		msgprms[3] = message_parm_3;
-		msgprmidx[3] = 0;
-		sprintf(message_parm_4, "%ld",
-			(long int) local_recptr->infile_buf_length);
-		msgprms[4] = message_parm_4;
-		msgprmidx[4] = 0;
-		sprintf(message_parm_5, "%ld", (long int) bytes_read);
-		msgprms[5] = message_parm_5;
-		msgprmidx[5] = 0;
-		send_msg(fsck_ERRONLOG, 6);
+		send_msg(fsck_ERRONLOG, FSCK_BADREAD_FSCKLOG, io_rc, fsck_READ,
+			 (long long) local_recptr->infile_agg_offset,
+			 (long int) local_recptr->infile_buf_length,
+			 (long int) bytes_read);
 	}
 	/*
 	 * We want to reset the buffer no matter what.  If is useful
@@ -500,7 +384,7 @@ int xchklog_initial_processing(struct fscklog_record *local_recptr)
 
 	if (pi_rc != 0) {
 		/*device open failed */
-		send_msg(fsck_CNTRESUPB, 0);
+		send_msg(fsck_CNTRESUPB);
 	} else {
 		/* device is open */
 		local_recptr->device_is_open = 1;
@@ -581,9 +465,9 @@ int xchklog_initial_processing(struct fscklog_record *local_recptr)
 	}
 
 	if (local_recptr->which_log == NEWLOG) {
-		send_msg(fsck_CHKLOGNEW, 0);
+		send_msg(fsck_CHKLOGNEW);
 	} else {
-		send_msg(fsck_CHKLOGOLD, 0);
+		send_msg(fsck_CHKLOGOLD);
 	}
 
 	return (pi_rc);
@@ -607,10 +491,7 @@ int open_device_read(char *Device)
 {
 	Dev_IOPort = open(Device, O_RDONLY, 0);
 	if (Dev_IOPort < 0) {
-		sprintf(message_parm_0, "%d", ERROR_FILE_NOT_FOUND);
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = 0;
-		send_msg(fsck_DEVOPENRDRC, 1);
+		send_msg(fsck_DEVOPENRDRC, ERROR_FILE_NOT_FOUND);
 		return ERROR_FILE_NOT_FOUND;
 	}
 
@@ -646,14 +527,12 @@ int open_outfile()
 			       default_logfile_name_len);
 		}
 	}
-	msgprms[0] = file_name;
-	msgprmidx[0] = 0;
 
 	outfp = fopen(file_name, "w");
 	if (outfp == NULL) {
 		/* output file open failed */
 		openof_rc = XCHKLOG_CANTOPENOUTFILE;
-		send_msg(fsck_XCHKLOGOPNFAIL, 1);
+		send_msg(fsck_XCHKLOGOPNFAIL, file_name);
 	} else {
 		/* output file is open */
 		local_recptr->outfile_is_open = -1;
@@ -670,10 +549,10 @@ int open_outfile()
 		 */
 		if (local_recptr->which_log == NEWLOG) {
 			/* most recent */
-			send_msg(fsck_XCHKLOGNEW, 1);
+			send_msg(fsck_XCHKLOGNEW, file_name);
 		} else {
 			/* previous */
-			send_msg(fsck_XCHKLOGOLD, 1);
+			send_msg(fsck_XCHKLOGOLD, file_name);
 		}
 	}
 	return (openof_rc);
@@ -766,59 +645,21 @@ int readwrite_device(int64_t dev_offset,
  * RETURNS:
  *	nothing
  */
-void record_msg(int mess_num, int num_parms)
+void record_msg(char *msg_txt)
 {
-	int prmidx;
+	char *msg;
 	char log_entry[4096];
 	int entry_length = sizeof (struct chklog_entry_hdr);
 	struct chklog_entry_hdr *hdptr;
-	int16_t *prmlen;
-	char *prmlit;
 	int buffer_bytes_left;
 
-	/* 
-	 * lookup any inserts not specified as literals
-	 */
-	memset((void *) msgs_txt_ptr, '\0', msgs_txt_maxlen);
-	prmidx = 0;
-	while (prmidx < num_parms) {
-		if (msgprmidx[prmidx] != 0) {
-			/* variable text insert */
-			msgprms[prmidx] = MsgText[msgprmidx[prmidx]];
-		}
-		prmidx += 1;
-	}
-
 	hdptr = (struct chklog_entry_hdr *) log_entry;
+	msg = &log_entry[entry_length];
+	strcpy(msg, msg_txt);
+	entry_length += strlen(msg_txt);
+	/* add null terminator to string */
+	log_entry[entry_length++] = '\0';
 
-	hdptr->msg_num = mess_num + JFSCHKLOG_FIRSTMSGNUM;
-	hdptr->num_parms = num_parms;
-
-	if (num_parms != 0) {
-		/* there are inserts */
-		prmlen = (short *) &(log_entry[entry_length]);
-		entry_length += num_parms * sizeof (short);
-		prmlit = (char *) &(log_entry[entry_length]);
-
-		prmidx = 0;
-		while (prmidx < num_parms) {
-			prmlen[prmidx] = strlen(msgprms[prmidx]);
-			strncpy(prmlit, msgprms[prmidx], prmlen[prmidx]);
-			entry_length += prmlen[prmidx];
-			/*
-			 * add a null terminator to the literal
-			 */
-			log_entry[entry_length] = '\0';
-			prmlen[prmidx] += 1;
-			entry_length += 1;
-			/*
-			 * set up for the next literal
-			 */
-			prmlit = (char *) &(log_entry[entry_length]);
-
-			prmidx += 1;
-		}
-	}
 	/*
 	 * round the length up so the next entry will
 	 * start on a doubleword (4 byte) boundary
@@ -874,7 +715,6 @@ void record_msg(int mess_num, int num_parms)
 int validate_super(int which_super)
 {
 	int vs_rc = 0;		/* assume the superblock is ok */
-	int ujfs_rc = 0;
 	int64_t bytes_on_device;
 	int64_t agg_blks_in_aggreg = 0, agg_blks_on_device =
 	    0, dev_blks_on_device;
@@ -890,71 +730,50 @@ int validate_super(int which_super)
 
 	if (memcmp(sb_ptr->s_magic, JFS_MAGIC, sizeof (sb_ptr->s_magic)) != 0) {
 		vs_rc = FSCK_BADSBMGC;
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = which_super;
-		send_msg(fsck_BADSBMGC, 1);
+		send_msg(fsck_BADSBMGC, fsck_ref_msg(which_super));
 	} else if (sb_ptr->s_version > JFS_VERSION) {
 		vs_rc = FSCK_BADSBVRSN;
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = which_super;
-		send_msg(fsck_BADSBVRSN, 1);
+		send_msg(fsck_BADSBVRSN, fsck_ref_msg(which_super));
 	} else {
 		/* the magic number and version number are correct so it
 		 * probably is a JFS superblock with the format we are expecting
 		 */
 
 		/* get physical device size */
-		ujfs_rc = ujfs_get_dev_size(Dev_IOPort, &bytes_on_device);
+		ujfs_get_dev_size(Dev_IOPort, &bytes_on_device);
 
 		dev_blks_on_device = bytes_on_device / Dev_blksize;
 
 		if (sb_ptr->s_pbsize != Dev_blksize) {
 			vs_rc = FSCK_BADSBOTHR1;
-			msgprms[0] = "1";
-			msgprmidx[0] = 0;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = which_super;
-			send_msg(fsck_BADSBOTHR, 2);
+			send_msg(fsck_BADSBOTHR, "1", fsck_ref_msg(which_super));
 		}
 		if (sb_ptr->s_l2pbsize != log2shift(Dev_blksize)) {
 			vs_rc = FSCK_BADSBOTHR2;
-			msgprms[0] = "2";
-			msgprmidx[0] = 0;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = which_super;
-			send_msg(fsck_BADSBOTHR, 2);
+			send_msg(fsck_BADSBOTHR, "2", fsck_ref_msg(which_super));
 		}
 		if (!inrange(sb_ptr->s_bsize, 512, 4096)) {
 			bad_bsize = -1;
 			vs_rc = FSCK_BADSBOTHR3;
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = which_super;
-			send_msg(fsck_BADSBBLSIZ, 1);
+			send_msg(fsck_BADSBBLSIZ, fsck_ref_msg(which_super));
 		} else {
 			/* else the filesystem block size is a legal value */
 			if (sb_ptr->s_l2bsize != log2shift(sb_ptr->s_bsize)) {
 				vs_rc = FSCK_BADSBOTHR4;
-				msgprms[0] = "4";
-				msgprmidx[0] = 0;
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = which_super;
-				send_msg(fsck_BADSBOTHR, 2);
+				send_msg(fsck_BADSBOTHR, "4",
+					 fsck_ref_msg(which_super));
 			}
 			if (sb_ptr->s_l2bfactor !=
 			    log2shift(sb_ptr->s_bsize / Dev_blksize)) {
 				vs_rc = FSCK_BADSBOTHR5;
-				msgprms[0] = "5";
-				msgprmidx[0] = 0;
-				msgprms[1] = message_parm_1;
-				msgprmidx[1] = which_super;
-				send_msg(fsck_BADSBOTHR, 2);
+				send_msg(fsck_BADSBOTHR, "5",
+					 fsck_ref_msg(which_super));
 			}
 			if (sb_ptr->s_bsize < Dev_blksize) {
 				bad_bsize = -1;
 				vs_rc = FSCK_BLSIZLTLVBLSIZ;
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = which_super;
-				send_msg(fsck_BLSIZLTLVBLSIZ, 1);
+				send_msg(fsck_BLSIZLTLVBLSIZ,
+					 fsck_ref_msg(which_super));
 			}
 		}
 
@@ -964,9 +783,7 @@ int validate_super(int which_super)
 
 		if (sb_ptr->s_size > dev_blks_on_device) {
 			vs_rc = FSCK_BADSBFSSIZ;
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = which_super;
-			send_msg(fsck_BADSBFSSIZ, 1);
+			send_msg(fsck_BADSBFSSIZ, fsck_ref_msg(which_super));
 		}
 #ifdef	_JFS_DFS_LFS
 		s_size_inbytes = sb_ptr->s_size * Dev_blksize;
@@ -976,35 +793,23 @@ int validate_super(int which_super)
 		    || ((s_size_inbytes - sum_inbytes) >= 1024)) {
 			/* the sum is greater or the difference is at least 1K */
 			vs_rc = FSCK_BADBLKCTTTL;
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = which_super;
-			send_msg(fsck_BADBLKCTTTL, 1);
+			send_msg(fsck_BADBLKCTTTL, fsck_ref_msg(which_super));
 		}
 #endif
 		/* must have JFS_OS2 or JFS_LINUX */
 		if (!(((sb_ptr->s_flag & JFS_OS2) == JFS_OS2)
 		      || ((sb_ptr->s_flag & JFS_LINUX) == JFS_LINUX))) {
 			vs_rc = FSCK_BADSBOTHR6;
-			msgprms[0] = "6";
-			msgprmidx[0] = 0;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = which_super;
-			send_msg(fsck_BADSBOTHR, 2);
+			send_msg(fsck_BADSBOTHR, "6", fsck_ref_msg(which_super));
 		}
 
 		if ((sb_ptr->s_flag & expected_flag) != expected_flag) {
 			vs_rc = FSCK_BADSBOTHR6;
-			msgprms[0] = "6";
-			msgprmidx[0] = 0;
-			msgprms[1] = message_parm_1;
-			msgprmidx[1] = which_super;
-			send_msg(fsck_BADSBOTHR, 2);
+			send_msg(fsck_BADSBOTHR, "6", fsck_ref_msg(which_super));
 		}
 		if (sb_ptr->s_agsize < (1 << L2BPERDMAP)) {
 			vs_rc = FSCK_BADSBAGSIZ;
-			msgprms[0] = message_parm_0;
-			msgprmidx[0] = which_super;
-			send_msg(fsck_BADSBAGSIZ, 1);
+			send_msg(fsck_BADSBAGSIZ, fsck_ref_msg(which_super));
 		} else {
 			/* else the alloc group size is possibly correct */
 			agg_blks_in_aggreg =
@@ -1016,9 +821,7 @@ int validate_super(int which_super)
 			agsize = (int64_t) 1 << agl2size;
 			if (sb_ptr->s_agsize != agsize) {
 				vs_rc = FSCK_BADAGFSSIZ;
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = which_super;
-				send_msg(fsck_BADSBAGSIZ, 1);
+				send_msg(fsck_BADSBAGSIZ, fsck_ref_msg(which_super));
 			}
 		}
 
@@ -1035,9 +838,7 @@ int validate_super(int which_super)
 			if (agg_blks_in_aggreg > agg_blks_on_device) {
 				/* wsp length is bad */
 				vs_rc = FSCK_BADSBFWSL1;
-				msgprms[0] = message_parm_0;
-				msgprmidx[0] = which_super;
-				send_msg(fsck_BADSBFWSL1, 1);
+				send_msg(fsck_BADSBFWSL1, fsck_ref_msg(which_super));
 			} else {
 				fsck_blkmap_size_pages =
 				    ((agg_blks_in_aggreg +
@@ -1060,9 +861,8 @@ int validate_super(int which_super)
 					 * workspace is incorrect
 					 */
 					vs_rc = FSCK_BADSBFWSL;
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = which_super;
-					send_msg(fsck_BADSBFWSL, 1);
+					send_msg(fsck_BADSBFWSL,
+						 fsck_ref_msg(which_super));
 				}
 				if (fsck_start_from_pxd !=
 				    fsck_blkmap_start_blks) {
@@ -1071,9 +871,8 @@ int validate_super(int which_super)
 					 * workspace is incorrect
 					 */
 					vs_rc = FSCK_BADSBFWSA;
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = which_super;
-					send_msg(fsck_BADSBFWSA, 1);
+					send_msg(fsck_BADSBFWSA,
+						 fsck_ref_msg(which_super));
 				}
 			}
 		}
@@ -1095,17 +894,15 @@ int validate_super(int which_super)
 					 * journal log is incorrect
 					 */
 					vs_rc = FSCK_BADSBFJLA;
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = which_super;
-					send_msg(fsck_BADSBFJLA, 1);
+					send_msg(fsck_BADSBFJLA,
+						 fsck_ref_msg(which_super));
 				}
 				agg_blks_in_aggreg += jlog_length_from_pxd;
 				if (agg_blks_in_aggreg > agg_blks_on_device) {
 					/* log length is bad */
 					vs_rc = FSCK_BADSBFJLL;
-					msgprms[0] = message_parm_0;
-					msgprmidx[0] = which_super;
-					send_msg(fsck_BADSBFJLL, 1);
+					send_msg(fsck_BADSBFJLL,
+						 fsck_ref_msg(which_super));
 				}
 			}
 		}
@@ -1144,7 +941,7 @@ int validate_superblock()
 
 	if (vsb_rc != 0) {
 		/* if read primary fails */
-		send_msg(fsck_CNTRESUPP, 0);
+		send_msg(fsck_CNTRESUPP);
 	} else {
 		/* got primary superblock */
 		which_sb = fsck_primary;
@@ -1153,13 +950,13 @@ int validate_superblock()
 
 	if (primary_sb_bad) {
 		/* can't use the primary superblock */
-		send_msg(fsck_SBBADP, 0);
+		send_msg(fsck_SBBADP);
 
 		/* get 2ndary */
 		vsb_rc = ujfs_get_superblk(Dev_IOPort, sb_ptr, 0);
 
 		if (vsb_rc != 0) {
-			send_msg(fsck_CNTRESUPS, 0);
+			send_msg(fsck_CNTRESUPS);
 		} else {
 			/* got secondary superblock */
 			which_sb = fsck_secondary;
@@ -1170,7 +967,7 @@ int validate_superblock()
 			/* secondary is ok */
 			vsb_rc = 0;
 		} else {
-			send_msg(fsck_SBBADS, 0);
+			send_msg(fsck_SBBADS);
 		}
 	}
 	if ((!primary_sb_bad) || (!secondary_sb_bad)) {
@@ -1179,9 +976,7 @@ int validate_superblock()
 		/* aggregate block size */
 		local_recptr->ag_blk_size = sb_ptr->s_bsize;
 
-		msgprms[0] = message_parm_0;
-		msgprmidx[0] = which_sb;
-		send_msg(fsck_XCHKLOGSBOK, 1);
+		send_msg(fsck_XCHKLOGSBOK, fsck_ref_msg(which_sb));
 	}
 
 	return (vsb_rc);
