@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines Corp., 2000-2002
+ *   Copyright (C) International Business Machines Corp., 2000-2004
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -122,6 +122,15 @@ struct dir_table_slot {
 #define DIR_INDEX_VALID 1
 #define DIR_INDEX_FREE  0
 
+#define DTSaddress(dir_table_slot, address64)\
+{\
+	(dir_table_slot)->addr1 = ((uint64_t)address64) >> 32;\
+	(dir_table_slot)->addr2 = __cpu_to_le32((address64) & 0xffffffff);\
+}
+
+#define addressDTS(dts)\
+	( ((uint64_t)((dts)->addr1)) << 32 | __le32_to_cpu((dts)->addr2) )
+
 /* compute number of slots for entry */
 #define	NDTLEAF_LEGACY(klen)	( ((2 + (klen)) + (15 - 1)) / 15 )
 #define	NDTLEAF	NDTINTERNAL
