@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -15,13 +15,15 @@
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 #ifndef	_H_JFS_LOGMGR
 #define _H_JFS_LOGMGR
 
+#ifndef	_H_JFS_SUPERBLOCK
+#include <uuid/uuid.h>
+#endif
+
 #include "jfs_types.h"
 #include "jfs_filsys.h"
-#include <uuid/uuid.h>
 
 /*
  *	log manager configuration parameters
@@ -62,7 +64,7 @@
 
 #define MAX_ACTIVE	128	/* Max active file systems sharing log */
 
-typedef struct {
+struct logsuper {
 	uint32_t magic;		/* 4: log lv identifier */
 	int32_t version;	/* 4: version number */
 	int32_t serial;		/* 4: log open/mount counter */
@@ -77,7 +79,7 @@ typedef struct {
 	uuid_t uuid;		/* 16: 128-bit journal uuid */
 	char label[16];		/* 16: journal label */
 	uuid_t active[MAX_ACTIVE];	/* 2048: active file systems list */
-} logsuper_t;
+};
 
 /* log flag: commit option (see jfs_filsys.h) */
 
@@ -115,7 +117,7 @@ typedef struct {
  * the two and h.eor and t.eor set to 8 (i.e. empty page). if (only) 
  * h.eor != t.eor they were set to the smaller of their two values.
  */
-typedef struct {
+struct logpage {
 	struct {		/* header */
 		int32_t page;	/* 4: log sequence page number */
 		int16_t rsrvd;	/* 2: */
@@ -129,7 +131,7 @@ typedef struct {
 		int16_t rsrvd;	/* 2: */
 		int16_t eor;	/* 2: normally the same as h.eor */
 	} t;
-} logpage_t;
+};
 
 #define LOGPHDRSIZE	8	/* log page header size */
 #define LOGPTLRSIZE	8	/* log page trailer size */
@@ -192,7 +194,7 @@ typedef struct {
 #define	LOG_FREEXAD		0x0002
 #define	LOG_FREEPXD		0x0001
 
-typedef struct lrd {
+struct lrd {
 	/*
 	 * type independent area
 	 */
@@ -343,16 +345,8 @@ typedef struct lrd {
 		 * no type-dependent information
 		 */
 	} log;
-} lrd_t;					/* (36) */
+};					/* (36) */
 
 #define	LOGRDSIZE	(sizeof(struct lrd))
 
-/*
- *	line vector descriptor
- */
-typedef struct {
-	int16_t offset;
-	int16_t length;
-} lvd_t;
-
 #endif				/* _H_JFS_LOGMGR */
