@@ -14,12 +14,13 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
  */
 #ifndef	_H_JFS_SUPERBLOCK
 #define _H_JFS_SUPERBLOCK
 
+#ifndef _H_JFS_LOGMGR
 #include <uuid/uuid.h>
+#endif
 
 /*
  *	jfs_superblock.h
