@@ -1,21 +1,20 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 2 of the License, or 
  *   (at your option) any later version.
- *
+ * 
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software
+ *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 #ifndef _H_JFS_TYPES
 #define	_H_JFS_TYPES
 
@@ -103,11 +102,11 @@ typedef struct {
 	( ((int64_t)((pxd)->addr1)) << 32 | __le32_to_cpu((pxd)->addr2))
 
 /* pxd list */
-typedef struct {
+struct pxdlist {
 	int16_t  maxnpxd;
 	int16_t  npxd;
 	pxd_t    pxd[8];
-} pxdlist_t;
+};
 
 
 /*
@@ -140,16 +139,16 @@ typedef struct {
 /*
  *      directory entry argument
  */
-typedef struct component_name {
+struct component_name {
 	int namlen;
 	UniChar *name;
-} component_t;
+};
 
 
 /*
  *	DASD limit information - stored in directory inode
  */
-typedef struct dasd {
+struct dasd {
 	uint8_t   thresh;		/* Alert Threshold (in percent) */
 	uint8_t   delta;		/* Alert Threshold delta (in percent)   */
 	uint8_t   rsrvd1;
@@ -158,7 +157,7 @@ typedef struct dasd {
 	uint8_t   rsrvd2[3];
 	uint8_t   used_hi;		/* DASD usage (in logical blocks)       */
 	uint32_t  used_lo;		/* DASD usage (in logical blocks)       */
-} dasd_t;
+};
 
 #define DASDLIMIT(dasdp) \
 	(((uint64_t)((dasdp)->limit_hi) << 32) + __le32_to_cpu((dasdp)->limit_lo))
