@@ -31,7 +31,7 @@
 #include <sys/ioctl.h>
 
 #if defined(__linux__) && defined(_IO) && !defined(BLKGETSIZE64)
-#define BLKGETSIZE64 _IOR(0x12, 114, sizeof(uint64_t))
+#define BLKGETSIZE64 _IOR(0x12, 114, size_t)
 #endif
 #if defined(__linux__) && defined(_IO) && !defined(BLKGETSIZE)
 #define BLKGETSIZE _IO(0x12,96)	/* return device size (sectors) */
