@@ -71,16 +71,18 @@ struct treeQelem {
 #define treeQ_elem_length sizeof(struct treeQelem)
 
 /*----------------------------------------------------------------------------
- * type dupall_blkrec describes one aggregate block which has been found to
- *                    have more than 1 inode claiming to own it.
+ * type dupall_blkrec describes range of aggregate blocks which has been
+ * found to have more than 1 inode claiming to own it.
  *
  */
 struct dupall_blkrec {
-	int64_t blk_number;
+	int64_t first_blk;
+	int64_t last_blk;
 	uint8_t first_ref_resolved;
 	uint8_t avail_byte;
 	uint16_t owner_count;
 	struct dupall_blkrec *next;
+	struct dupall_blkrec *prev;
 };
 
 #define dupall_blkrec_length sizeof(struct dupall_blkrec)
@@ -290,11 +292,12 @@ struct fsck_inode_record {
 	unsigned involved_in_dups:1;
 
 	unsigned crrct_cumm_blks:1;
-	unsigned avail_flagbit_1:1;
+	unsigned rebuild_dirtable:1;
 	unsigned inlineea_on:1;
 	unsigned inlineea_off:1;
 
-	unsigned avail_flagbits:4;
+	unsigned check_dir_index:1;
+	unsigned avail_flagbits:3;
 	/*        end of flag bits           */
 	int8_t inode_type;	/* 1 : see constants above          */
 
@@ -838,6 +841,16 @@ struct fsck_agg_record {
 	int8_t node_buf_write;
 	char aggrec_rsvdu[3];	/* pad to quadword boundary        */
 
+	/* ****** INTERNAL/LEAF DNODE I/O BUFFER ****** */
+
+	char dnodbuf_info_eyecatcher[8];
+	char *dnode_buf_ptr;
+	uint32_t dnode_buf_length;
+	uint32_t dnode_buf_data_len;
+	int64_t dnode_agg_offset;
+	int8_t dnode_buf_write;
+	char aggrec_rsvduu[3];	/* pad to quadword boundary        */
+
 	/* **************************** instantiation of imap AG tables */
 
 	char agg_AGTbl_eyecatcher[8];
