@@ -630,7 +630,5 @@ void ujfs_swap_fscklog_entry_hdr(struct fscklog_entry_hdr *hdptr)
 	/* fscklog_entry_hdr in fscklog.h */
 
 	hdptr->entry_length = __le16_to_cpu(hdptr->entry_length);
-	hdptr->msg_num = __le16_to_cpu(hdptr->msg_num);
-	hdptr->num_parms = __le16_to_cpu(hdptr->num_parms);
 }
 #endif				/* BIG ENDIAN */
