@@ -202,6 +202,7 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 	int32_t lowest_lr_byte = 2 * LOGPSIZE + LOGPHDRSIZE;
 	int32_t highest_lr_byte = 0;
 	int log_has_wrapped = 0;
+	int in_use;
 
 	rc = open_outfile();
 
@@ -216,7 +217,7 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 		 * Find and open the log
 		 */
 		LogOpenMode = O_RDONLY;
-		rc = findLog(fd);
+		rc = findLog(fd, &in_use);
 
 		if (rc < 0) {
 			printf("JFS_LOGDUMP:Error occurred when open/read device\n");
@@ -384,8 +385,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 				switch (ld.type) {
 				case LOG_COMMIT:
 					fprintf(outfp,
-						"LOG_COMMIT     (type = d %d)     logtid = d %d\n",
-						ld.type, ld.logtid);
+						"LOG_COMMIT   (type = d %d)   logtid = d %d   aggregate = d %d\n",
+						ld.type, ld.logtid, ld.aggregate);
 					fprintf(outfp, "\n");
 					fprintf(outfp, "\tdata length = d %d\n", ld.length);
 
@@ -395,8 +396,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 					fprintf(outfp,
 						"++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n");
 					fprintf(outfp,
-						"LOG_MOUNT      (type = d %d)     logtid = d %d\n",
-						ld.type, ld.logtid);
+						"LOG_MOUNT   (type = d %d)   logtid = d %d   aggregate = d %d\n",
+						ld.type, ld.logtid, ld.aggregate);
 					fprintf(outfp, "\n");
 					fprintf(outfp, "\tdata length = d %d\n", ld.length);
 					fprintf(outfp,
@@ -407,8 +408,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 					fprintf(outfp,
 						"****************************************************************\n");
 					fprintf(outfp,
-						"LOG_SYNCPT     (type = d %d)     logtid = d %d\n",
-						ld.type, ld.logtid);
+						"LOG_SYNCPT   (type = d %d)   logtid = d %d    aggregate = d %d\n",
+						ld.type, ld.logtid, ld.aggregate);
 					fprintf(outfp, "\n");
 					fprintf(outfp, "\tdata length = d %d\n", ld.length);
 					fprintf(outfp, "\tsync = x %x\n", ld.log.syncpt.sync);
@@ -426,8 +427,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 
 				case LOG_REDOPAGE:
 					fprintf(outfp,
-						"LOG_REDOPAGE   (type = d %d)     logtid = d %d\n",
-						ld.type, ld.logtid);
+						"LOG_REDOPAGE   (type = d %d)   logtid = d %d    aggregate = d %d\n",
+						ld.type, ld.logtid, ld.aggregate);
 					fprintf(outfp, "\n");
 					fprintf(outfp, "\tdata length = d %d    ", ld.length);
 					disp_redopage(&ld);
@@ -435,8 +436,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 
 				case LOG_NOREDOPAGE:
 					fprintf(outfp,
-						"LOG_NOREDOPAGE   (type = d %d)     logtid = d %d\n",
-						ld.type, ld.logtid);
+						"LOG_NOREDOPAGE   (type = d %d)   logtid = d %d   aggregate = d %d\n",
+						ld.type, ld.logtid, ld.aggregate);
 					fprintf(outfp, "\n");
 					fprintf(outfp, "\tdata length = d %d    ", ld.length);
 					disp_noredopage(&ld);
@@ -444,8 +445,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 
 				case LOG_NOREDOINOEXT:
 					fprintf(outfp,
-						"LOG_NOREDOINOEXT (type = d %d)     logtid = d %d\n",
-						ld.type, ld.logtid);
+						"LOG_NOREDOINOEXT (type = d %d)   logtid = d %d   aggregate = d %d\n",
+						ld.type, ld.logtid, ld.aggregate);
 					fprintf(outfp, "\n");
 					fprintf(outfp, "\tdata length = d %d    ", ld.length);
 					disp_noredoinoext(&ld);
@@ -453,8 +454,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 
 				case LOG_UPDATEMAP:
 					fprintf(outfp,
-						"LOG_UPDATEMAP    (type = d %d)     logtid = d %d\n",
-						ld.type, ld.logtid);
+						"LOG_UPDATEMAP   (type = d %d)   logtid = d %d   aggregate = d %d\n",
+						ld.type, ld.logtid, ld.aggregate);
 					fprintf(outfp, "\n");
 					fprintf(outfp, "\tdata length = d %d    ", ld.length);
 					disp_updatemap(&ld);
@@ -462,8 +463,8 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 
 				default:
 					fprintf(outfp,
-						"*UNRECOGNIZED*   (type = d %d)     logtid = d %d\n",
-						ld.type, ld.logtid);
+						"*UNRECOGNIZED*   (type = d %d)   logtid = d %d   aggregate = d %d\n",
+						ld.type, ld.logtid, ld.aggregate);
 					fprintf(outfp, "\n");
 					fprintf(outfp, "\tdata length = d %d\n", ld.length);
 					fprintf(outfp, "\n");
