@@ -404,6 +404,13 @@ int logRead(int32_t logaddr,	/* address of log record to read */
 	}
 	ujfs_swap_lrd(ld);
 
+	/*
+	 * Legacy code used device number in ld->aggegate.  This code only
+	 * supported a single volume attached to the journal
+	 */
+	if (ld->aggregate > MAX_ACTIVE)
+		ld->aggregate = 0;
+
 	/* read the data if there is any */
 	if (ld->length > 0) {
 		if (ld->length > LOGPSIZE * 2) {
