@@ -189,7 +189,7 @@ extern int doUpdateMap(struct lrd *);
 extern int v_fsck_send_msg(int, const char *, int, ...);
 extern int alloc_wrksp(uint32_t, int, int, void **);
 
-extern int open_by_label(uuid_t, int, int, char *);
+extern int open_by_label(uuid_t, int, int, char *, int *);
 extern char log_device[];
 /*
  * forward references
@@ -486,6 +486,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	int highest_lr_byte = 0;
 	int log_has_wrapped = 0;
 	int logend;
+	int in_use;
 
 	/*
 	 * store away the indicator of which aggregate superblock
@@ -502,7 +503,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	/*
 	 * validate that the log is not currently in use;
 	 */
-	rc = findLog(fd);
+	rc = findLog(fd, &in_use);
 	if (rc < 0) {
 		fsck_send_msg(lrdo_DEVOPNREADERROR);
 		return (rc);
@@ -550,7 +551,12 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		if ((rc = fstat(log.fd, &st)))
 			goto error_out;
 
-		log.devnum = dev_to_kdev(st.st_rdev);
+		log.devnum = st.st_rdev;
+
+		if (in_use) {
+			fsck_send_msg(lrdo_LOGINUSE);
+			return LOG_IN_USE;
+		}
 	}
 
 	if (logsup.state == LOGREDONE) {
@@ -868,7 +874,8 @@ int doMount(struct lrd *ld)
 {				/* pointer to record descriptor */
 	int vol, status;
 
-	vol = 0;
+	vol = ld->aggregate;
+
 	status = vopen[vol].status;
 	DBG_TRACE(("Logredo:domount: status=%d\n", status))
 
@@ -897,7 +904,8 @@ int openVol(int vol)
 		if (!uuid_compare(vopen[vol].uuid, primary_vol.uuid))
 			vopen[vol].fd = primary_vol.fd;
 		else {
-			vopen[vol].fd = open_by_label(vopen[vol].uuid, 0, 0, NULL);
+			vopen[vol].fd = open_by_label(vopen[vol].uuid, 0, 0,
+						      NULL, NULL);
 			if (vopen[vol].fd < 0)
 				return ENOENT;
 		}
@@ -1165,11 +1173,12 @@ int bflush(int32_t k,		/*  The index in bufhdr that describes buf */
  * 		the log device.
  *
  */
-int findLog(int fd)
+int findLog(int fd, int *in_use)
 {
 	struct logsuper logsup;
 	struct superblock sb;
 
+	*in_use = 0;
 	/*
 	 * try the LV as file system with in-line log
 	 */
@@ -1212,22 +1221,27 @@ int findLog(int fd)
 		if (log_device[0]) {
 			log.fd = open(log_device, LogOpenMode, 0);
 			if (log.fd < 0) {
-				printf("Invalid journal specified (%s)\n", log_device);
-				goto by_uuid;
+				log.fd = open(log_device, O_RDONLY, 0);
+				if (log.fd < 0) {
+					printf("Invalid journal specified (%s)\n",
+					       log_device);
+					goto by_uuid;
+				}
+				*in_use = 1;
 			}
 			ujfs_rw_diskblocks(log.fd, LOGPNTOB(LOGSUPER_B),
 					   sizeof (struct logsuper), &logsup, GET);
 			ujfs_swap_logsuper(&logsup);
 			if ((logsup.magic != LOGMAGIC) || (uuid_compare(logsup.uuid, sb.s_loguuid))) {
 				close(log.fd);
+				*in_use = 0;
 				goto by_uuid;
 			}
 			log.location = OUTLINELOG;
-
 			return 0;
 		}
 	      by_uuid:
-		log.fd = open_by_label(sb.s_loguuid, 0, 1, NULL);
+		log.fd = open_by_label(sb.s_loguuid, 0, 1, NULL, in_use);
 
 		if (log.fd >= 0) {
 			log.location |= OUTLINELOG;
