@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -14,15 +14,7 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- *   MODULE_NAME:		initmap.h
- *
- *   COMPONENT_NAME: 	jfsformat
- *
- *   FUNCTIONS: 	none
- *
  */
-
 #ifndef H_INITMAP
 #define H_INITMAP
 
@@ -30,10 +22,10 @@
 #define FREE		0x2
 #define BADBLOCK	0x4
 
-int32_t calc_map_size(int64_t, struct dinode *, int32_t, int32_t *, uint32_t);
-int32_t markit(int32_t, uint32_t);
-int32_t record_LVM_BadBlks( int32_t, int32_t, int32_t, struct dinode *, int64_t );
-int32_t verify_last_blocks( int32_t, int32_t, struct dinode * );
-int32_t write_block_map(int32_t, int64_t, int32_t);
+int calc_map_size(int64_t, struct dinode *, int, int *, unsigned);
+int markit(int, unsigned);
+int record_LVM_BadBlks( int, int, int, struct dinode *, int64_t );
+int verify_last_blocks( int, int, struct dinode * );
+int write_block_map(int, int64_t, int);
 
 #endif	/* H_INITMAP */
